#!/usr/bin/env python3
"""
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

"""

from resource_management import Hook


class BeforeSetKeytabHook(Hook):
  def hook(self, env):
    """
    This will invoke the before-ANY hook which contains all of the user and group creation logic.
    Keytab regeneration requires all users are already created, which is usually done by the
    before-INSTALL hook. However, if the keytab regeneration is executed as part of an upgrade,
    then the before-INSTALL hook never ran.

    :param env:
    :return:
    """
    self.run_custom_hook("before-ANY")


if __name__ == "__main__":
  BeforeSetKeytabHook().execute()
